Ntt

Trait Ntt 

pub(crate) trait Ntt {
    type Output;

    // Required method
    fn ntt(&self) -> Self::Output;
}
The Number Theoretic Transform (NTT) is a variant of the Discrete Fourier Transform (DFT) defined over a finite field that turns costly polynomial multiplications into simple coefficient-wise multiplications modulo a fixed prime.

Required Associated Types

Required Methods

fn ntt(&self) -> Self::Output

Implementations on Foreign Types

Source

impl Ntt for Polynomial<BaseField>

Algorithm 9: NTT

Source

impl<K: ArraySize> Ntt for Vector<BaseField, K>

Implementors