NttInverse

Trait NttInverse 

pub(crate) trait NttInverse {
    type Output;

    // Required method
    fn ntt_inverse(&self) -> Self::Output;
}
The inverse NTT is the reverse of the Number Theoretic Transform, converting coefficient-wise products back into standard polynomial form while preserving correctness modulo the same prime.

Required Associated Types

Required Methods

fn ntt_inverse(&self) -> Self::Output

Implementations on Foreign Types

Source

impl NttInverse for NttPolynomial<BaseField>

Algorithm 10: NTT^{-1}

Source

impl<K: ArraySize> NttInverse for NttVector<BaseField, K>

Implementors